public inbox for pbs-devel@lists.proxmox.com
 help / color / mirror / Atom feed
From: Christian Ebner <c.ebner@proxmox.com>
To: pbs-devel@lists.proxmox.com
Subject: [PATCH proxmox-backup v3 29/30] api: encryption keys: allow to toggle the archived state for keys
Date: Tue, 14 Apr 2026 14:59:22 +0200	[thread overview]
Message-ID: <20260414125923.892345-30-c.ebner@proxmox.com> (raw)
In-Reply-To: <20260414125923.892345-1-c.ebner@proxmox.com>

Adapt the api endpoint to not only allow to archive a key, but rather
allow to toggle its archived state by setting or stripping the
optional `archived-at` timestamp in the config.

Expose this in the ui by adapting the corresponding button
accordingly.

Signed-off-by: Christian Ebner <c.ebner@proxmox.com>
---
changes since version 2:
- not present in previous version

note: kept this as separate patch for now as unsure if this should be
split into 2 dedicated api points instead?

 pbs-config/src/encryption_keys.rs  | 10 ++++++----
 src/api2/config/encryption_keys.rs |  6 +++---
 www/config/EncryptionKeysView.js   | 24 +++++++++++++++++-------
 3 files changed, 26 insertions(+), 14 deletions(-)

diff --git a/pbs-config/src/encryption_keys.rs b/pbs-config/src/encryption_keys.rs
index fd5989a98..2120ae861 100644
--- a/pbs-config/src/encryption_keys.rs
+++ b/pbs-config/src/encryption_keys.rs
@@ -196,16 +196,18 @@ pub fn delete_key(id: &str, mut config: SectionConfigData) -> Result<bool, Error
     Ok(false)
 }
 
-/// Mark the key as archived by setting the `archived-at` timestamp.
+/// Toggle the key's archived state by setting or dropping the `archived-at` timestamp.
 pub fn archive_key(id: &str, mut config: SectionConfigData) -> Result<(), Error> {
     let mut key: CryptKey = config.lookup(ENCRYPTION_KEYS_CFG_TYPE_ID, id)?;
 
     if key.archived_at.is_some() {
-        bail!("key already marked as archived");
+        // was archived, mark as active again
+        key.archived_at = None;
+    } else {
+        // was not archived, mark as archived
+        key.archived_at = Some(proxmox_time::epoch_i64());
     }
 
-    key.archived_at = Some(proxmox_time::epoch_i64());
-
     config.set_data(id, ENCRYPTION_KEYS_CFG_TYPE_ID, &key)?;
     let raw = CONFIG.write(ENCRYPTION_KEYS_CFG_FILENAME, &config)?;
     // drops config lock
diff --git a/www/config/EncryptionKeysView.js b/www/config/EncryptionKeysView.js
index 35f147799..77542932d 100644
--- a/www/config/EncryptionKeysView.js
+++ b/www/config/EncryptionKeysView.js
@@ -38,7 +38,7 @@ Ext.define('PBS.config.EncryptionKeysView', {
             }).show();
         },
 
-        archiveEncryptionKey: function () {
+        toggleEncryptionKeyArchiveState: function () {
             let me = this;
             let view = me.getView();
             let selection = view.getSelection();
@@ -246,14 +246,24 @@ Ext.define('PBS.config.EncryptionKeysView', {
         '-',
         {
             xtype: 'proxmoxButton',
-            text: gettext('Archive'),
-            handler: 'archiveEncryptionKey',
+            text: gettext('Toggle Archived'),
+            handler: 'toggleEncryptionKeyArchiveState',
             dangerous: true,
-            confirmMsg: Ext.String.format(
-                gettext('Archiving will render the key unusable to encrypt new content, proceed?'),
-            ),
+            confirmMsg: (item) => {
+                let msg;
+                if (item.data['archived-at']) {
+                    msg = gettext(
+                        'Are you sure you want to restore the archived key to be active again?',
+                    );
+                } else {
+                    msg = gettext(
+                        'Archiving will render the key unusable to encrypt new content, proceed?',
+                    );
+                }
+                return Ext.String.format(msg);
+            },
             disabled: true,
-            enableFn: (item) => item.data.type === 'sync' && !item.data['archived-at'],
+            enableFn: (item) => item.data.type === 'sync',
         },
         '-',
         {
diff --git a/src/api2/config/encryption_keys.rs b/src/api2/config/encryption_keys.rs
index d3097929d..a10430b25 100644
--- a/src/api2/config/encryption_keys.rs
+++ b/src/api2/config/encryption_keys.rs
@@ -126,8 +126,8 @@ pub fn create_key(
         permission: &Permission::Privilege(&["system", "encryption-keys", "{id}"], PRIV_SYS_MODIFY, false),
     },
 )]
-/// Mark the key by given id as archived, no longer usable to encrypt contents.
-pub fn archive_key(
+/// Toggle the archive state for the key by given id, archived keys are no longer usable to encrypt contents.
+pub fn toggle_key_archive_state(
     id: String,
     digest: Option<String>,
     _rpcenv: &mut dyn RpcEnvironment,
@@ -210,7 +210,7 @@ fn encryption_key_in_use(id: &str) -> Result<Option<Vec<String>>, Error> {
 }
 
 const ITEM_ROUTER: Router = Router::new()
-    .post(&API_METHOD_ARCHIVE_KEY)
+    .post(&API_METHOD_TOGGLE_KEY_ARCHIVE_STATE)
     .delete(&API_METHOD_DELETE_KEY);
 
 pub const ROUTER: Router = Router::new()
-- 
2.47.3





  parent reply	other threads:[~2026-04-14 12:59 UTC|newest]

Thread overview: 40+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-04-14 12:58 [PATCH proxmox{,-backup} v3 00/30] fix #7251: implement server side encryption support for push sync jobs Christian Ebner
2026-04-14 12:58 ` [PATCH proxmox v3 01/30] pbs-api-types: define en-/decryption key type and schema Christian Ebner
2026-04-14 12:58 ` [PATCH proxmox v3 02/30] pbs-api-types: sync job: add optional cryptographic keys to config Christian Ebner
2026-04-14 12:58 ` [PATCH proxmox-backup v3 03/30] sync: push: use tracing macros instead of log Christian Ebner
2026-04-14 12:58 ` [PATCH proxmox-backup v3 04/30] datastore: blob: implement async reader for data blobs Christian Ebner
2026-04-14 12:58 ` [PATCH proxmox-backup v3 05/30] datastore: manifest: add helper for change detection fingerprint Christian Ebner
2026-04-14 12:58 ` [PATCH proxmox-backup v3 06/30] pbs-key-config: introduce store_with() for KeyConfig Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 07/30] pbs-config: implement encryption key config handling Christian Ebner
2026-04-14 14:32   ` Michael Köppl
2026-04-15  6:48     ` Christian Ebner
2026-04-15  8:03       ` Daniel Kral
2026-04-15  8:21         ` Christian Ebner
2026-04-15  8:06       ` Thomas Lamprecht
2026-04-14 12:59 ` [PATCH proxmox-backup v3 08/30] pbs-config: acls: add 'encryption-keys' as valid 'system' subpath Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 09/30] ui: expose 'encryption-keys' as acl subpath for 'system' Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 10/30] sync: add helper to check encryption key acls and load key Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 11/30] api: config: add endpoints for encryption key manipulation Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 12/30] api: config: check sync owner has access to en-/decryption keys Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 13/30] api: config: allow encryption key manipulation for sync job Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 14/30] sync: push: rewrite manifest instead of pushing pre-existing one Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 15/30] api: push sync: expose optional encryption key for push sync Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 16/30] sync: push: optionally encrypt data blob on upload Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 17/30] sync: push: optionally encrypt client log on upload if key is given Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 18/30] sync: push: add helper for loading known chunks from previous snapshot Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 19/30] fix #7251: api: push: encrypt snapshots using configured encryption key Christian Ebner
2026-04-15 14:49   ` Michael Köppl
2026-04-15 15:25     ` Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 20/30] ui: define and expose encryption key management menu item and windows Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 21/30] ui: expose assigning encryption key to sync jobs Christian Ebner
2026-04-15 14:49   ` Michael Köppl
2026-04-15 15:20     ` Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 22/30] sync: pull: load encryption key if given in job config Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 23/30] sync: expand source chunk reader trait by crypt config Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 24/30] sync: pull: introduce and use decrypt index writer if " Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 25/30] sync: pull: extend encountered chunk by optional decrypted digest Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 26/30] sync: pull: decrypt blob files on pull if encryption key is configured Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 27/30] sync: pull: decrypt chunks and rewrite index file for matching key Christian Ebner
2026-04-14 12:59 ` [PATCH proxmox-backup v3 28/30] sync: pull: decrypt snapshots with matching encryption key fingerprint Christian Ebner
2026-04-14 12:59 ` Christian Ebner [this message]
2026-04-14 12:59 ` [PATCH proxmox-backup v3 30/30] docs: add section describing server side encryption for sync jobs Christian Ebner

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260414125923.892345-30-c.ebner@proxmox.com \
    --to=c.ebner@proxmox.com \
    --cc=pbs-devel@lists.proxmox.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Service provided by Proxmox Server Solutions GmbH | Privacy | Legal